import lineColumn = require('line-column');
import LruCache = require('lru-cache');
import { CodeInfo, CodeLocation } from './code';
export declare enum FeatureType {
    ReturningMultipleValue = "ReturningMultipleValue",
    Recursion = "Recursion",
    FirstClassFunction = "FirstClassFunction",
    PureFunction = "PureFunction",
    ViewFunction = "ViewFunction",
    ConstantFunction = "ConstantFunction",
    FunctionModifier = "FunctionModifier",
    NamedCall = "NamedCall",
    FreeFunction = "FreeFunction",
    ReturnVariable = "ReturnVariable",
    FallbackFunction = "FallbackFunction",
    ReceiveEtherFunction = "ReceiveEtherFunction",
    FunctionOverloading = "FunctionOverloading",
    Loop = "Loop",
    CrossContractInvocationHighLevel = "CrossContractInvocationHighLevel",
    CrossContractInvocationLowLevel = "CrossContractInvocationLowLevel",
    Send = "Send",
    Transfer = "Transfer",
    CreatingContractViaNew = "CreatingContractViaNew",
    ExceptionRequireAssertRevertThrow = "ExceptionRequireAssertRevertThrow",
    ExceptionTryCatch = "ExceptionTryCatch",
    SingleInheritance = "SingleInheritance",
    MultipleInheritance = "MultipleInheritance",
    SuperVirtualMethodLookup = "SuperVirtualMethodLookup",
    FunctionOverriding = "FunctionOverriding",
    FunctionModifierOverriding = "FunctionModifierOverriding",
    AbstractContract = "AbstractContract",
    Interface = "Interface",
    FunctionVisibility = "FunctionVisibility",
    StateVariableVisibility = "StateVariableVisibility",
    Library = "Library",
    Array = "Array",
    Struct = "Struct",
    NestedArrayOrStruct = "NestedArrayOrStruct",
    Enum = "Enum",
    Event = "Event",
    ConstantAndImmutableStateVariable = "ConstantAndImmutableStateVariable",
    SpdxLicenseIdentifier = "SpdxLicenseIdentifier",
    ImportRenaming = "ImportRenaming",
    NatSpecComment = "NatSpecComment",
    PragmaSolidityVersion = "PragmaSolidityVersion",
    PragmaSmtChecker = "PragmaSmtChecker",
    ManualGasControl = "ManualGasControl",
    InlineAssembly = "InlineAssembly",
    UnicodeLiteral = "UnicodeLiteral",
    HexadecimalLiteral = "HexadecimalLiteral",
    EtherUnit = "EtherUnit",
    TimeUnit = "TimeUnit"
}
export interface FeatureSite {
    literal?: string;
    location?: CodeLocation;
    index?: number;
}
export declare type CheckFunction = (context: CheckerContext) => Promise<FeatureSite[]>;
export declare type FeatureTypeName = string;
export interface FeatureChecker {
    name: FeatureTypeName;
    check: CheckFunction;
}
export declare type LineColumnFinder = ReturnType<typeof lineColumn>;
export declare type Filename = string;
export interface CheckerContext {
    codeInfo: CodeInfo;
    cache: LruCache<Filename, LineColumnFinder>;
}
export declare type CheckerOutputFormatString = 'map' | 'object' | 'json';
export interface CheckerConfig<T extends CheckerOutputFormatString> {
    outputFormat: T;
}
export declare type CheckerOutputType<T extends CheckerOutputFormatString> = T extends 'map' ? Map<FeatureTypeName, FeatureSite[]> : T extends 'object' ? Record<FeatureTypeName, FeatureSite[]> : T extends 'json' ? string : never;
