"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildDefaultEngineWithConfig = exports.buildDefaultEngine = void 0;
var feature_1 = require("../model/feature");
var engine_1 = require("../infra/engine");
var checkers_1 = require("./checkers");
var defaultCheckers = [
    {
        name: feature_1.FeatureType.ReturningMultipleValue,
        check: checkers_1.checkReturningMultipleValue,
    },
    {
        name: feature_1.FeatureType.ReturningMultipleValue,
        check: checkers_1.checkReturningMultipleValue,
    },
    {
        name: feature_1.FeatureType.Recursion,
        check: checkers_1.checkRecursion,
    },
    {
        name: feature_1.FeatureType.FirstClassFunction,
        check: checkers_1.checkFirstClassFunction,
    },
    {
        name: feature_1.FeatureType.PureFunction,
        check: checkers_1.checkPureFunction,
    },
    {
        name: feature_1.FeatureType.ViewFunction,
        check: checkers_1.checkViewFunction,
    },
    {
        name: feature_1.FeatureType.ConstantFunction,
        check: checkers_1.checkConstantFunction,
    },
    {
        name: feature_1.FeatureType.FunctionModifier,
        check: checkers_1.checkFunctionModifier,
    },
    {
        name: feature_1.FeatureType.NamedCall,
        check: checkers_1.checkNamedCall,
    },
    {
        name: feature_1.FeatureType.FreeFunction,
        check: checkers_1.checkFreeFunction,
    },
    {
        name: feature_1.FeatureType.ReturnVariable,
        check: checkers_1.checkReturnVariable,
    },
    {
        name: feature_1.FeatureType.FallbackFunction,
        check: checkers_1.checkFallbackFunction,
    },
    {
        name: feature_1.FeatureType.ReceiveEtherFunction,
        check: checkers_1.checkReceiveEtherFunction,
    },
    {
        name: feature_1.FeatureType.FunctionOverloading,
        check: checkers_1.checkFunctionOverloading,
    },
    {
        name: feature_1.FeatureType.Loop,
        check: checkers_1.checkLoop,
    },
    {
        name: feature_1.FeatureType.CrossContractInvocationHighLevel,
        check: checkers_1.checkCrossContractInvocationHighLevel,
    },
    {
        name: feature_1.FeatureType.CrossContractInvocationLowLevel,
        check: checkers_1.checkCrossContractInvocationLowLevel,
    },
    {
        name: feature_1.FeatureType.Transfer,
        check: checkers_1.checkTransfer,
    },
    {
        name: feature_1.FeatureType.Send,
        check: checkers_1.checkSend,
    },
    {
        name: feature_1.FeatureType.CreatingContractViaNew,
        check: checkers_1.checkCreatingContractViaNew,
    },
    {
        name: feature_1.FeatureType.ExceptionRequireAssertRevertThrow,
        check: checkers_1.checkExceptionRequireAssertRevertThrow,
    },
    {
        name: feature_1.FeatureType.ExceptionTryCatch,
        check: checkers_1.checkExceptionTryCatch,
    },
    {
        name: feature_1.FeatureType.SingleInheritance,
        check: checkers_1.checkSingleInheritance,
    },
    {
        name: feature_1.FeatureType.MultipleInheritance,
        check: checkers_1.checkMultipleInheritance,
    },
    {
        name: feature_1.FeatureType.SuperVirtualMethodLookup,
        check: checkers_1.checkSuperVirtualMethodLookup,
    },
    {
        name: feature_1.FeatureType.FunctionOverriding,
        check: checkers_1.checkFunctionOverriding,
    },
    {
        name: feature_1.FeatureType.FunctionModifierOverriding,
        check: checkers_1.checkFunctionModifierOverriding,
    },
    {
        name: feature_1.FeatureType.AbstractContract,
        check: checkers_1.checkAbstractContract,
    },
    {
        name: feature_1.FeatureType.Interface,
        check: checkers_1.checkInterface,
    },
    {
        name: feature_1.FeatureType.FunctionVisibility,
        check: checkers_1.checkFunctionVisibility,
    },
    {
        name: feature_1.FeatureType.StateVariableVisibility,
        check: checkers_1.checkStateVariableVisibility,
    },
    {
        name: feature_1.FeatureType.Library,
        check: checkers_1.checkLibrary,
    },
    {
        name: feature_1.FeatureType.Array,
        check: checkers_1.checkArray,
    },
    {
        name: feature_1.FeatureType.Struct,
        check: checkers_1.checkStruct,
    },
    {
        name: feature_1.FeatureType.NestedArrayOrStruct,
        check: checkers_1.checkNestedArrayOrStruct,
    },
    {
        name: feature_1.FeatureType.Enum,
        check: checkers_1.checkEnum,
    },
    {
        name: feature_1.FeatureType.Event,
        check: checkers_1.checkEvent,
    },
    {
        name: feature_1.FeatureType.ConstantAndImmutableStateVariable,
        check: checkers_1.checkConstantAndImmutableStateVariable,
    },
    {
        name: feature_1.FeatureType.SpdxLicenseIdentifier,
        check: checkers_1.checkSpdxLicenseIdentifier,
    },
    {
        name: feature_1.FeatureType.ImportRenaming,
        check: checkers_1.checkImportRenaming,
    },
    {
        name: feature_1.FeatureType.NatSpecComment,
        check: checkers_1.checkNatSpecComment,
    },
    {
        name: feature_1.FeatureType.PragmaSolidityVersion,
        check: checkers_1.checkPragmaSolidityVersion,
    },
    {
        name: feature_1.FeatureType.PragmaSmtChecker,
        check: checkers_1.checkPragmaSmtChecker,
    },
    {
        name: feature_1.FeatureType.ManualGasControl,
        check: checkers_1.checkManualGasControl,
    },
    {
        name: feature_1.FeatureType.InlineAssembly,
        check: checkers_1.checkInlineAssembly,
    },
    {
        name: feature_1.FeatureType.UnicodeLiteral,
        check: checkers_1.checkUnicodeLiteral,
    },
    {
        name: feature_1.FeatureType.HexadecimalLiteral,
        check: checkers_1.checkHexadecimalLiteral,
    },
    {
        name: feature_1.FeatureType.EtherUnit,
        check: checkers_1.checkEtherUnit,
    },
    {
        name: feature_1.FeatureType.TimeUnit,
        check: checkers_1.checkTimeUnit,
    },
];
function addDefaultCheckers(engine) {
    for (var _i = 0, defaultCheckers_1 = defaultCheckers; _i < defaultCheckers_1.length; _i++) {
        var checker = defaultCheckers_1[_i];
        engine.addChecker(checker);
    }
    return engine;
}
function buildDefaultEngine() {
    return addDefaultCheckers(engine_1.CheckerEngine.new());
}
exports.buildDefaultEngine = buildDefaultEngine;
function buildDefaultEngineWithConfig(config) {
    return addDefaultCheckers(engine_1.CheckerEngine.newWithConfig(config));
}
exports.buildDefaultEngineWithConfig = buildDefaultEngineWithConfig;
